This package was made to allow working with the TED EU database efficiently. It scrapes pages and parses their contents to find relevant documents and data. The output is a dataframe with the most important pieces of information (~10% of all fields). The initial use case was with Zeiss RMS, finding the market size for electron microscopes. Working with the data, competitor analysis emerged as an additional use case. 